[![CIViCpy tests](https://github.com/griffithlab/civicpy/actions/workflows/tests.yml/badge.svg)](https://github.com/griffithlab/civicpy/actions/workflows/tests.yml) [![Coverage Status](https://coveralls.io/repos/github/griffithlab/civicpy/badge.svg?branch=master)](https://coveralls.io/github/griffithlab/civicpy?branch=master)

# CIViCpy
You have reached the code repository for CIViCpy, a python client and analysis toolkit for
 the Clinical Interpretations of Variants in Cancer knowledgebase ([CIViC](https://civicdb.org)).
 
 Please visit our [project homepage](http://civicpy.org) to get started.

